class nginx::config (
  $nginx                = 'nginx',
  $worker_processes     = 'auto',
  $worker_connections   = 768,
  $worker_rlimit_nofile = false,
  $multi_accept         = 'on',
  $client_max_body_size = '5m',
  $delete_default_site  = false,
  $keepalive_timeout    = 65,
  $flood_protection     = false,
  $cache_open_fd        = false,
  $gzipping             = false,
  $ensure               = 'present',) {
  class { "nginx::install": nginx => $nginx }

  include nginx::service

  #  remove default site

  if $delete_default_site {
    file { "default-site":
      path    => "/etc/nginx/sites-enabled/default",
      ensure  => absent,
      notify  => Class["nginx::service"],
      require => Class["nginx::install"],
    }
  }

  if $worker_rlimit_nofile {
    file { "/etc/default/nginx":
      path    => "/etc/default/nginx",
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
      content => template("nginx/nginx.erb"),
      ensure  => $ensure,
      notify  => Class["nginx::service"],
      require => Class["nginx::install"],
    }
  }

  #  nginx conf
  file { "nginx.conf":
    path    => "/etc/nginx/nginx.conf",
    ensure  => $ensure,
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template("nginx/nginx.conf.erb"),
    require => Class["nginx::install"],
    notify  => Class["nginx::service"],
  }
}
