define nginx::config::php_site (
  $ensure         = present,
  $server_name    = [],
  $ip             = '0.0.0.0',
  $port           = 80,
  $default_server = false,
  $base_dir       = '/var/www',
  $root_dir       = undef,
  $ssl            = undef, # optional, required, exclusive
  $ssl_cert       = undef,
  $ssl_port       = 443,
  $fastcgi_pass   = 'php5-fpm', # predefined nginx fastcgi upstream
  $index          = 'index.php',
  $template       = 'php5-fpm-site') {
  if $root_dir {
    $root = $root_dir
  } else {
    $root = "${base_dir}/${title}"
  }
  realize Nginx::Config::Upstream[$fastcgi_pass]

  #  if $ssl {
  #    if $ssl_cert {
  #      $ssl_cert_name = $ssl_cert
  #    } else {
  #      $ssl_cert_name = $server_name[0]
  #    }
  #    realize Ssl::Cert::Files[$ssl_cert_name]
  #  }

  file { $title:
    path    => "/etc/nginx/sites-available/$title",
    ensure  => $ensure,
    owner   => 'root',
    group   => 'root',
    mode    => 0644,
    content => template("nginx/sites/${template}.erb"),
    require => Class["nginx::install"],
    notify  => Class["nginx::service"],
  }

  case $ensure {
    absent  : {
      file { "${title}-enabled":
        path   => "/etc/nginx/sites-enabled/${title}",
        ensure => $ensure,
        notify => Class["nginx::service"],
      }
    }
    present : {
      file { "${title}-enabled":
        path    => "/etc/nginx/sites-enabled/${title}",
        ensure  => link,
        target  => "/etc/nginx/sites-available/${title}",
        require => File["/etc/nginx/sites-available/${title}"],
        notify  => Class["nginx::service"],
      }
    }
  }
}
