define nginx::config::rails_app (
  $ensure         = present,
  $server_name    = [],
  $ip             = '0.0.0.0',
  $port           = 80,
  $default_server = false,
  $app_root       = "/opt/$name",
  $ssl            = undef, # optional, required, exclusive
  $ssl_cert       = undef,
  $ssl_port       = 443,
  $proxy_pass     = '127.0.0.1:3000',
  $index          = 'index.html',
  $template       = 'rails-app-site') {
  realize Nginx::Config::Upstream[$proxy_pass]

  file { $title:
    path    => "/etc/nginx/sites-available/$title",
    ensure  => $ensure,
    owner   => 'root',
    group   => 'root',
    mode    => 0644,
    content => template("nginx/sites/${template}.erb"),
    require => Class["nginx::install"],
    notify  => Class["nginx::service"],
  }

  case $ensure {
    absent  : {
      file { "${title}-enabled":
        path   => "/etc/nginx/sites-enabled/${title}",
        ensure => $ensure,
        notify => Class["nginx::service"],
      }
    }
    present : {
      file { "${title}-enabled":
        path    => "/etc/nginx/sites-enabled/${title}",
        ensure  => link,
        target  => "/etc/nginx/sites-available/${title}",
        require => File["/etc/nginx/sites-available/${title}"],
        notify  => Class["nginx::service"],
      }
    }
  }
}
